@@ -44,7 +44,7 @@
 //! ```
 
 #![no_std]
-#![doc(html_root_url = "https://docs.rs/qed/1.0.0")]
+#![doc(html_root_url = "https://docs.rs/qed/1.1.0")]
 
 // Ensure code blocks in README.md compile
 #[cfg(all(doctest, any(target_pointer_width = "32", target_pointer_width = "64")))]
@@ -217,3 +217,101 @@ macro_rules! lossless_cast_u32_to_usize {
         num as usize
     }};
 }
+
+/// Asserts that two types have the same size at compile time.
+///
+/// See also [`const_assert!`].
+///
+/// # Examples
+///
+/// ```
+/// qed::const_assert_size_eq!(u8, i8);
+/// qed::const_assert_size_eq!([u32; 4], i128);
+/// qed::const_assert_size_eq!(&[u8], &str);
+/// ```
+///
+/// The following fails to compile because the types have different sizes:
+///
+/// ```compile_fail
+/// qed::const_assert_size_eq!(u8, u64);
+/// ```
+#[macro_export]
+macro_rules! const_assert_size_eq {
+    ($left:ty, $right:ty $(,)?) => {
+        const _: () = {
+            let _ = ::core::mem::transmute::<$left, $right>;
+        };
+    };
+}
+
+#[cfg(test)]
+mod tests {
+    use core::num::NonZeroU8;
+
+    #[test]
+    fn const_assert_no_warnings() {
+        crate::const_assert!(true);
+        crate::const_assert!(NonZeroU8::new(0).is_none());
+        crate::const_assert!(NonZeroU8::new(29).is_some());
+    }
+
+    #[test]
+    fn const_assert_eq_no_warnings() {
+        crate::const_assert_eq!(i8::BITS, u8::BITS);
+        crate::const_assert_eq!(u8::BITS, u8::BITS);
+    }
+
+    #[test]
+    fn const_assert_eq_no_warnings_literals() {
+        crate::const_assert_eq!(0, 0);
+        crate::const_assert_eq!(29_i32, 29_i32);
+    }
+
+    #[test]
+    fn const_assert_ne_no_warnings() {
+        crate::const_assert_ne!(u32::BITS, u8::BITS);
+    }
+
+    #[test]
+    fn const_assert_ne_no_warings_literals() {
+        crate::const_assert_ne!(9, 99);
+        crate::const_assert_ne!(0_i32, 29_i32);
+    }
+
+    #[test]
+    fn const_assert_matches_no_warnings() {
+        crate::const_assert_matches!(NonZeroU8::new(0), None);
+        crate::const_assert_matches!(NonZeroU8::new(29), Some(x) if x.get() == 29);
+    }
+
+    #[test]
+    fn const_assert_matches_no_warnings_literals() {
+        crate::const_assert_matches!(None::<i8>, None);
+        crate::const_assert_matches!(Some(0_i8), Some(_));
+
+        crate::const_assert_matches!(None::<i8>, None::<i8>);
+        crate::const_assert_matches!(Some(0_i8), Some(0_i8));
+    }
+
+    #[test]
+    fn lossless_cast_u32_usize_no_warnings() {
+        let n = crate::lossless_cast_u32_to_usize!(29_u32);
+        assert_eq!(n, 29_usize);
+    }
+
+    #[test]
+    fn lossless_cast_u32_usize_no_warnings_const() {
+        const N: usize = crate::lossless_cast_u32_to_usize!(29_u32);
+        assert_eq!(N, 29_usize);
+    }
+
+    #[test]
+    fn size_eq_reference_transmute_no_warnings() {
+        crate::const_assert_size_eq!(&[u8], &str);
+    }
+
+    #[test]
+    fn size_eq_pointer_transmute_no_warnings() {
+        crate::const_assert_size_eq!(*mut u8, *const u8);
+    }
+}
